\name{Fst}
\alias{Fst}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Calculates the Fst from the conditional kinship matrix }
\description{
  Calculates the Fst from a conditional kinship matrix.
}
\usage{
Fst(rval, N)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{rval}{ is a conditional kinship matrix, normally obtained by the function 'R' in the Malecot library. }
  \item{N}{ the vector of effective populations size, nominally obtained by dividing the total population size by three }
}
\details{
  The use of the Fst function follows Harpending and Jenkins 1974, and Jorde 1982. It gives an estimate of Wright's Fst, which is a measure of between-subdivision genetic heterogeneity.
}
\value{
  Fst returns one numeric value.
}
\references{ Harpending, H. C. and T. jenkins. 1974. !Kung population structure. In: J. F. Crow and C. F. Denniston (eds.), Genetic distance, pp 137-161. Plenum Press, NY.

Jorde, L. B. 1982. The genetic structure of the Utah mormons: migration analysis. Human Biology 54(3): 583-597. }
\author{ Federico C. F. Calboli \email{f.calboli@ucl.ac.uk} }
\note{ ... }
\examples{
# Swedlund data again...
data(P); data(S); data(N)
# starting with how many cycles to equilibrium
x<-Mal.eq(S,P,N)
# calculation of phi
phi<-Phi(S,P,N,x)
# calcutaion of the conditional kinship matrix
cond<-R(phi,N)
# finally! we get the Fst value
fst<-Fst(cond,N)
fst
}
\keyword{ array }
\keyword{ manip }
\keyword{ misc }

\eof
\name{Mal.eq}
\alias{Mal.eq}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Calculates the asymptotic generation for the Malecot model }
\description{
  Mal.eq calculates the Malecot model iteratively, stopping when one more cycle adds 0 to every value of the matrix obtained by the model. Once equilibrium is reached, Mal.eq returns the number of cycles ("generations") needed to reach it.
}
\usage{
Mal.eq(S, P, N)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{S}{ is the Sistematic pressure matrix. }
  \item{P}{ is the colum-stochastic migration matrix. }
  \item{N}{ is the vector of effective population size. }
}
\details{
  The use of mal.eq is necessary before the calculation of the Malecot model proper because the value returned by Mal.eq is one of the arguments of the Malecot model function Phi.
}
\value{
  Returns one numeric value.
}
\references{ Imaizumi, Y., N. E. Morton and D. E. Harris. 1970. Isolation by distance in artificial populations. Genetics 66: 569-582.

Jorde, L. B. 1982. The genetic structure of the Utah mormons: migration analysis. Human Biology 54(3): 583-597.

Swedlund, A. C., L. B. Jorde and J. H. Mielke. 1984. Population structure in the Connecticut valley. I. Marital migration. American Journal of Physical Anthropology 65: 61-70 }
\author{ Federico C. F. Calboli \email{f.calboli@ucl.ac.uk} }
\note{
  This function has been coerced to use "only" six significant digits.
  ...
  }
\seealso{ \code{\link{Phi}} for the function using the output of 'Mal.eq' }
\examples{
# the data is originally from a paper by Swedlund et al. 1984.
data(S); data(P); data(N)
Mal.eq(S,P,N)
}
\keyword{ array }
\keyword{ iteration }
\keyword{ methods }

\eof
\name{N}
\alias{N}
\docType{data}
\title{ Effective population vector }
\description{
  A vector giving the effective population size for n populations. The effective population size is calculated as the total population divided by three.
}
\usage{data(N)}
\format{
  A 12 elements vector.
}
\details{
  This data comes for Swedlund et al. 1984.
}
\source{
  Swedlund, A. C., L. B. Jorde and J. H. Mielke. 1984. Population structure in the Connecticut valley. I. Marital migration. American Journal of Physical Anthropology 65: 61-70
}
\examples{
data(N)
}
\keyword{datasets}

\eof
\name{P}
\alias{P}
\docType{data}
\title{ Column stochastic migration matrix }
\description{
  A column stochastic migration matrix for 12 populations.
}
\usage{data(P)}
\format{
  A 12 by 12 square matrix
}
\details{
  This data comes for Swedlund et al. 1984.
}
\source{
  Swedlund, A. C., L. B. Jorde and J. H. Mielke. 1984. Population structure in the Connecticut valley. I. Marital migration. American Journal of Physical Anthropology 65: 61-70
}
\examples{
data(P)
}
\keyword{datasets}

\eof
\name{Phi}
\alias{Phi}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Calculates a kinship matrix using the Malecot Migration Model }
\description{
  Calculates a kinship matrix using the Malecot Migration Model, in the form described by L. B. Jorde 1982.
}
\usage{
Phi(S, P, N, n)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{S}{ the sistematic pressure matrix, where the diagonal elements are 1-sk, with sk the sistematic pressure for the k-th population, and the non diagonal elements are 0 }
  \item{P}{ the column stochastic migration matrix, possibly obtained using col.sto on the "raw" migration matrix }
  \item{N}{ the vector of effective populations, where each element is the population size for all the n populations divided by 3 }
  \item{n}{ the number of iterations needed to reach the equilibrium, calculated by the function Mal.eq }
}
\details{
  The Malecot model is simply an iterative markow-chain-like process that gives rise to an asymptotic growth curve, so that an equilibrium is reached after a number of iterations.
}
\value{
  Returns a square and symmetrical matrix.
}
\references{ Imaizumi, Y., N. E. Morton and D. E. Harris. 1970. Isolation by distance in artificial populations. Genetics 66: 569-582.

Jorde, L. B. 1982. The genetic structure of the Utah mormons: migration analysis. Human Biology 54(3): 583-597. }
\author{ Federico C. F. Calboli \email{f.calboli@ucl.ac.uk} }
\note{ ... }
\seealso{ \code{\link{Mal.eq}} for the function generating the number of cycles needed to reach the asymptotic value }
\examples{
# using Swedlund data again...
data(S); data(P); data(N)
x<-Mal.eq(S,P,N)
phi<-Phi(S,P,N,x)
phi
}
\keyword{ array }
\keyword{ iteration }

\eof
\name{R}
\alias{R}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Calculates a Conditional Kinship matrix }
\description{
  The function R calculates a R conditional kinship matrix starting from a kinship matrix obtained by the applicatio of the Malecot migration model on a colum stochastic migration matrix.
}
\usage{
R(PHI, N)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{PHI}{ \code{PHI} is a square and symmetrical kinship matrix, possibly the output of the function Phi }
  \item{N}{ \code{N} is the effectiove population vector }
}
\details{
  Much more useful than the Phi matrix, the conditional kinship R matrix is the basis for further analysis by means of Mantel tests, Procrustes rotations and cluster analysis.
}
\value{
  Returns a square symmetrical matrix.
}
\references{ Jorde, L. B. 1982. The genetic structure of the Utah mormons: migration analysis. Human Biology 54(3): 583-597. }
\author{ Federico C. F. Calboli \email{f.calboli@ucl.ac.uk} }
\note{ ... }
\seealso{ \code{\link{Phi}} for the calculation of "absolute" kinship values }
\examples{
# using Swedlund data again...
data(S); data(P); data(N)
x<-Mal.eq(S,P,N)
phi<-Phi(S,P,N,x)
cond.mat<-R(phi,N)
cond.mat
}
\keyword{ array }
\keyword{ manip }

\eof
\name{S}
\alias{S}
\docType{data}
\title{ Systematic pressure matrix }
\description{
  Systematic pressure matrix obtained by creating a square matix, where the non diagonal elements are all 0 and the diagonal elements are calculated as 1-Sk, where Sk is the systematic pressure for the k-th population.
}
\usage{data(S)}
\format{
  A 12 by 12 square matrix.
}
\details{
  This data comes for Swedlund et al. 1984.
}
\source{
  Swedlund, A. C., L. B. Jorde and J. H. Mielke. 1984. Population structure in the Connecticut valley. I. Marital migration. American Journal of Physical Anthropology 65: 61-70
}
\examples{
data(S)
}
\keyword{datasets}

\eof
\name{col.sto}
\alias{col.sto}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Turns a Migration Matrix into a Column Stochastic Matrix }
\description{
  Calculates the column stochastic matrix starting from the raw migration matrix. For each column, it divides each term by the column sum. Then it returns the thus "normalized by column" matrix, ready to be used in the Malecot migration model.
}
\usage{
col.sto(x)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{ the raw data migration matrix }
}
\details{
  The Malecot model uses a transformation of the raw migration data; in the "Malecot" library the use of a column stochastic matrix follows Imaizumi 1970 and Swedlund 1984.
}
\value{
  col.sto is used on a an object of class "matrix" and returns an object of class "matrix".
}
\references{ Imaizumi, Y., N. E. Morton and D. E. Harris. 1970. Isolation by distance in artificial populations. Genetics 66: 569-582.

Jorde, L. B. 1982. The genetic structure of the Utah mormons: migration analysis. Human Biology 54(3): 583-597. }
\author{ Federico C. F. Calboli \email{f.calboli@ucl.ac.uk} }
\note{ ... }
\examples{
data(raw.mig)
new.mig.mat<-col.sto(raw.mig)
new.mig.mat
}
\keyword{ manip }
\keyword{ array }

\eof
\name{mtx.exp}
\alias{mtx.exp}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Calculates the n-th power of a matrix }
\description{
  Calculates the n-th power of a matrix.
}
\usage{
mtx.exp(X, n)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{X}{ a square matrix }
  \item{n}{ the exponential value }
}
\details{
  This function calculates (efficiently!) the n-th power of a matrix.
}
\value{
  Takes a matrix and returns a matrix.
}
\references{ ~put references to the literature/web site here ~ }
\author{ Vincente Canto Cassola and Martin Maechler }
\note{ Original code by VCC "beautyfied" by MM }
\examples{
test<-matrix(c(1:16), 4,4)
pow.test<-mtx.exp(test,10)
pow.test
}
\keyword{ array }
\keyword{ manip }
\keyword{ methods }

\eof
\name{raw.mig}
\alias{raw.mig}
\docType{data}
\title{ A raw migration data }
\description{
  Made up raw dataset, created as if count data for marital migration were put into matrix form.
}
\usage{data(raw.mig)}
\format{
  A 4 by 4 square matrix.
}
\details{
  Completely made up for pedagogical purposes.
}

\examples{
data(raw.mig)
col.sto(raw.mig)
}
\keyword{datasets}

\eof
\name{sym.P}
\alias{sym.P}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Calculate the symmetric column stochastic matrix }
\description{
  Used to turn the asymmetric column stochastic matrix into a symmetric column stochastic matric.
}
\usage{
sym.P(x)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{ \code{x} is a column stochastic matrix }
}
\details{
  The function calculates the symmetric matrix from the asymmetric column stochastic matrix, leaving the diagonal unchanged and averaging m[i,j] and m[j,i] as (m[i,j]+m[j,i])/2. The computed average substitutes each pair of values in the new symmetric column stochastic matrix.
}
\value{
  Returns a matrix.
}
\references{ Jorde, L. B. 1982. The genetic structure of the Utah mormons: migration analysis. Human Biology 54(3): 583-597. }
\author{ Federico C. F. Calboli \email{f.calboli@ucl.ac.uk} }
\note{ ... }
\examples{
data(P)
symmetric<-sym.P(P)
}
\keyword{ array }
\keyword{ manip }

\eof
